# Developer guide (moved)

This document was split into smaller Diátaxis pages.

## Setup

- [Dev setup](how-to/dev-setup.md)

## Understanding the codebase

- [Architecture](explanation/architecture.md)
- [Routing & sessions](explanation/routing-and-sessions.md)
- [Module map](explanation/module-map.md)

## Reference

- [Specification](reference/specification.md)
- [Plugin API](reference/plugin-api.md)
- [Environment variables](reference/env-vars.md)
- [Telegram transport](reference/transports/telegram.md)
- [Runners](reference/runners/index.md)

## Extending Takopi

- [Write a plugin](how-to/write-a-plugin.md)
- [Add a runner](how-to/add-a-runner.md)
